@@ -3,7 +3,7 @@ Test the utility for splitting words.
 """
 import pytest
 
-from humps.main import separate_words
+from humps.main import _separate_words
 
 
 @pytest.mark.parametrize(
@@ -43,7 +43,7 @@ def test_separate_words(input_str, expected_output):
     :param input_str: String that will be transformed.
     :param expected_output: The expected transformation.
     """
-    output = separate_words(input_str)
+    output = _separate_words(input_str)
     assert output == expected_output, "{} != {}".format(
         output, expected_output
     )
